package App::Jawk;
use strict;

# this is just here for the documentation

1;

=head1 NAME

App::Jawk -- Documentation for jawk

=head1 SYNOPSIS

See documentation for the script 'jawk'

=head1 DESCRIPTION

See documentation for the script L<jawk>

=head1 COPYRIGHT

Copyright (c) 2010-2012 Josh Rabinowitz, All Rights Reserved.

=head1 AUTHORS

Josh Rabinowitz

=cut    

